
#include "gda-mysql-types.h"
#include "gda-mysql-recset.h"


Gda_MYSQL_Recordset*
gda_mysql_recset_new()
{
  Gda_MYSQL_Recordset* rc = g_new0(Gda_MYSQL_Recordset, 1);
  return rc;
}

void
gda_mysql_recset_free(Gda_MYSQL_Recordset* rs)
{
  g_free(rs);
}


gint
gda_MYSQL_recset_close(Gda_MYSQL_Recordset* rs)
{
  return 0;
}



